@@ -21,7 +21,6 @@ fm1 <- lmer(Reaction ~ ns(Days,2) + (1|Subject), sleepstudy)
 fm2 <- lmer(Reaction ~ poly(Days,2) + (1|Subject), sleepstudy)
 fm3 <- lmer(Reaction ~ poly(Days,2,raw=TRUE) + (1|Subject), sleepstudy)
 
-
 newdat0 <- data.frame(Days=unique(sleepstudy$Days))
 newdat <- data.frame(Days=5:12)
 tmpf <- function(fit) {
@@ -31,9 +30,23 @@ tmpf <- function(fit) {
     with(newdat,lines(Days,predict(fit,REform=NA,newdata=newdat),col=5))
 }
 
+stopifnot(all.equal(predict(fm2,newdat,REform=NA),
+                    predict(fm3,newdat,REform=NA)))
+
 ## pictures
 tmpf(fm1)
 tmpf(fm2)
 tmpf(fm3)
-stopifnot(all.equal(predict(fm2,newdat,REform=NA),
-                    predict(fm3,newdat,REform=NA)))
+
+## test for GLMMs
+set.seed(101)
+d <- data.frame(y=rbinom(10,size=1,prob=0.5),
+                x=1:10,
+                f=factor(rep(1:5,each=2)))
+gm1 <- glmer(y ~ poly(x,2) + (1|f), d, family=binomial)
+gm2 <- glmer(y ~ poly(x,2,raw=TRUE) + (1|f), d, family=binomial)
+
+newdat <- data.frame(x=c(1,4,6))
+stopifnot(all.equal(predict(gm1,newdat,REform=NA),
+                    predict(gm2,newdat,REform=NA),tol=3e-6))
+
