@@ -1,6 +1,7 @@
 stopifnot(require(lme4))
 ## "MEMSS" is just 'Suggest' -- must still work, when it's missing:
-if(data(ergoStool, package="MEMSS") != "ergoStool") {
+if (suppressWarnings(!require(MEMSS,quietly=TRUE)) ||
+    (data(ergoStool, package="MEMSS") != "ergoStool")) {
     cat("'ergoStool' data from package 'MEMSS' is not available --> skipping test\n")
     quit('no')
 }
